@@ -3,3 +3,5 @@ from allen.exceptions import *
 from allen.video import *
 from allen.test_record import *
 from allen.solution import *
+from allen.exam import *
+from allen.addon_classes import *
