@@ -1,6 +1,7 @@
 from dataclasses import dataclass
 from allen.solution import SubjectSolution
 from datetime import datetime
+from typing import List, Optional
 
 
 @dataclass(frozen=True, order=True)
@@ -44,7 +45,7 @@ class TestRecord:
     @classmethod
     def from_json(cls, json_obj: dict, client):
         """
-        Deserialize the video json dict to a TestRecord object.
+        Deserialize the test json dict to a TestRecord object.
 
         :param json_obj: The json dictionary to deserialize.
         :param client: The allen client.
@@ -68,12 +69,12 @@ class TestRecord:
         rank = int(json_obj.get('Rank'))
         name = json_obj.get('TestName')
         date = json_obj.get('TestDate')
-        id = json_obj.get('TestID')
+        test_id = json_obj.get('TestID')
         cls.client = client
 
-        return TestRecord(bio, phy, chem, math, total, percentage, rank, name, date, id)
+        return TestRecord(bio, phy, chem, math, total, percentage, rank, name, date, test_id)
 
-    def get_subject_solutions(self) -> list[SubjectSolution]:
+    def get_subject_solutions(self) -> List[SubjectSolution]:
         """
         Get the solutions of the test.
 
@@ -89,7 +90,7 @@ class TestRecord:
 
         return solutions
 
-    def get_test_date(self) -> str:
+    def get_test_date(self) -> Optional[str]:
         """
         Returns the date of the test in ``Thursday : 01 January 1970`` format.
 
